	program test
	use GnuFigureMakerClass 
    
    implicit none
 
    type(GnuFigureMaker) :: fig0, fig1, fig2, fig3, fig4
    type(GnuDataSeries) :: GnuSeriesXX(1:4), GnuSeriesY(1:4), GnuSeriesYs(1), &
                             GnuSeriesX, GnuSeriesXYZ,GnuSeriesXYZ1, GnuSeriesX3D, &
                                GnuSeriesY3D, GnuSeriesRnd1(1:2), GnuSeriesRnd(1) 

	integer, parameter	:: n1=50, n2=50, n3=50, n4=50, nx=50
    integer, parameter	:: nsq=n1*n1
	
    integer       :: x(nx,1:8), x1(n1) 
    real*8        :: y1(n1), y2(n2), y3(n3), y4(n4) 
 
    real*8        :: x3D(n1), y3D(n1)
    real*8        :: xyz2(n1,n1), xyz3(n1,n1)
    
    real          :: rmatrix1(nsq) 
    real          :: rmatrix2(nsq) 
    real          :: rmatrix(n1)
    
    real          :: grid(1:11)
    
	integer		  :: i,j,k , ios
 
    integer, dimension(1) :: seed = (/3/) 
 
!   generate data 

    call random_seed (PUT=seed)

    call random_number( rmatrix2 ) 
    call random_number( rmatrix )
 
    rmatrix2=rmatrix2*rmatrix2 
    
    rmatrix1=.05
    
    do  i=1,n1
        do j=1,n1
            
		    x3D(i)=real(i)/10.
            y3D(j)=real(j)/10.
 
            xyz2(i,j)=cos( real(i)*real(j)/200. ) !3d matrix format
            xyz3(i,j)=sin( real(i)*real(j)/100. ) !3d matrix format
    end do
    end do 

    x=0
	do  i=1,n1
        x(i,1)=(1997+i)
        x(i,2)=1
		x(i,3)=1
    end do

    x1=0
	do  i=1,n1
        x1(i)=i
    end do
    
	do  i=1,n1
		y1(i)=6.0*i/n1
    end do
    
	do  i=1,n2
		y2(i)=5.0*i/n2
    end do
    
	do  i=1,n3
		y3(i)=sin(7.0*i/n3)
    end do
    
    do  i=1,n4
		y4(i)=8.0*i/n4
    end do
    
!   plot data 
    
!   =============================================== SIMPLE 2D PLOT ===========================================================================================
    
    call fig0 % setTitle(title = '2D plot')
    call fig0 % setTimeFormat(fmt="%Y")
    call fig0 % setAxisLabels(xaxis='time', yaxis='y')
    
    call fig0 % addLabel(label = 'label 1', xpos=epoch(2024), ypos=3.6d0, rotation=27 )
    call fig0 % addLabel(label = 'label 2', xpos=epoch(2028), ypos=2.8d0, rotation=20 )
    call fig0 % addLabel(label = 'label 3', xpos=epoch(2018), ypos=0.5d0, rotation=-27 )
    
    call fig0 % addArrow(from_xpos=epoch(2042),  from_ypos=0.2d0, to_xpos=epoch(2042), to_ypos=3.94d0)
    
    call fig0 % clearLegend()
    
    call constructTSeries(DataSeries = GnuSeriesX, &
                                      title    = 'calendar time', &
                                      series   = x  ) 
    
    call constructSeries(DataSeries = GnuSeriesYs(1), &
                                      title    = 'series1', &
                                      series   = y1,  &
                                      linecolor=colorBankR(1),      &
                                      linewidth='4',     &
                                      linestyle='-',     &
                                      offset=0           )  
    
    call constructSeries(DataSeries = GnuSeriesY(1), &
                                      title    = 'series1', &
                                      series   = y1,  &
                                      linecolor=colorBankR(1),      &
                                      linewidth='4',     &
                                      linestyle='-',     &
                                      offset=0           )    
    
    call constructSeries(DataSeries = GnuSeriesY(2), &
                                      title    = 'series2', &
                                      series   = y2, &
                                      linecolor=colorBankG(1),      &
                                      linewidth='4',     &
                                      linestyle='-',     &
                                      offset=0           ) 
    
    call constructSeries(DataSeries = GnuSeriesY(3), &
                                      title    = 'series3', &
                                      series   = y3, &                                       
                                      linecolor=colorBankB(1), &
                                      linewidth='4',     &
                                      linestyle='-',     &
                                      offset=0           )   
      
    call constructSeries(DataSeries = GnuSeriesY(4), &
                                      title    = 'series4', &
                                      series   = y4,  &                                      
                                      linecolor=colorBankB(4), &
                                      linewidth='4',     &
                                      linestyle='-',     &
                                      offset=0           )   
    
    call fig0 % gnuplot2D(  DataX=GnuSeriesX,  &
                            DataY=GnuSeriesY(1:3),  &
                            terminal='pdf',    & 
                            label='myfig_2D'            )
    
    call fig0 % gnuplot2D(  DataX=GnuSeriesX,  &
                            DataY=GnuSeriesY(1:3),  &
                            terminal='screen',    & 
                            label='myfig_2D'            )
      
   
!=============================================== 2D SUBPLOT ===========================================================================================
    
    call fig1 % setTitle(title = '2D multi plot')
    call fig1 % setTimeFormat( fmt="%Y")
    call fig1 % setAxisLabels(xaxis='year', yaxis='y')
    
    call fig1 % clearLegend()
    
    call constructTSeries(DataSeries = GnuSeriesXX(1), &
                                       title  = "calendar time", &
                                       series = x,               &
                                       unit   ='year'            )    
    
    call constructSeries(DataSeries = GnuSeriesXX(2),             &
                                       title  = "integers",       &
                                       series = x1,               &
                                       unit   ='number'           )   
    
    call constructSeries(DataSeries = GnuSeriesXX(3),             &
                                       title  = "reals",          &
                                       series = real(x1),         &
                                       unit   ='real number'      )   
    
    call constructSeries(DataSeries = GnuSeriesXX(4),             &
                                       title  = "reals*8",        &
                                       series = real(x1),         &
                                       unit   ='real*8 number'    )   
    
    
    call constructSeries(DataSeries = GnuSeriesY(1),             &
                                      title    = "series1",      &
                                      series   = y1,             &
                                      linecolor=colorBankR(1),   &
                                      linewidth='3',             &
                                      linestyle='-',             &
                                      offset=0,                   &
                                      unit='y1'                  )    
    
    call constructSeries(DataSeries = GnuSeriesY(2),             &
                                      title    = "series2",      &
                                      series   = y2,             &
                                      linecolor=colorBankG(2),   &
                                      linewidth='3',             &
                                      linestyle='-',             &
                                      offset=0,                   &
                                      unit='y2'                  )    
    
    call constructSeries(DataSeries = GnuSeriesY(3),             &
                                      title    = "series3",      &
                                      series   = y3,             &                                       
                                      linecolor=colorBankB(3),   &
                                      linewidth='3',             &
                                      linestyle='-',             &
                                      offset=0,                   &
                                      unit='y3'                  )    
      
    call constructSeries(DataSeries = GnuSeriesY(4), &
                                      title    = "series4", &
                                      series   = y4,  &                                      
                                      linecolor=colorBankB(4), &
                                      linewidth='3',     &
                                      linestyle='-',     &
                                      offset=0,                   &
                                      unit='y4'                  )    
    
    call fig1 % gnusubplot2D(    fontsize=8, &
                                    numrows=2,             & 
                                    numcols=2,             &
                                    DataX=GnuSeriesXX(1:4),  &
                                    DataY=GnuSeriesY(1:4),  &
                                    terminal='pdf',    & 
                                    label='myfig_multi'       )
    
    call fig1 % gnusubplot2D(    fontsize=8, &
                                    numrows=2,             & 
                                    numcols=2,             &
                                    DataX=GnuSeriesXX(1:4),  &
                                    DataY=GnuSeriesY(1:4),  &
                                    terminal='screen',    & 
                                    label='myfig_multi'       )
        
!   =============================================== 3D PLOT ===========================================================================================
    
    call fig2 % setTitle(title = '3D plot')
    call fig2 % setAxisLabels(xaxis='x', yaxis='y', zaxis='z')
    call fig2 % setDimension(dim=3)
   
       
    pm3d=.true. !set filling that will distinguish the plots
    
    call constructSeries(DataSeries = GnuSeriesX3D,    &
                                      title    = "X", &
                                      series   = x3D   ) 
       
    call constructSeries(DataSeries = GnuSeriesY3D,    &
                                      title    = "Y", &
                                      series   = y3D   ) 
    
    call constructSeries(DataSeries = GnuSeriesXYZ,    &
                                      title    = "XYZ", &
                                      series   = xyz2   ) 
   
    call fig2 % gnuplot3D(DataX=GnuSeriesX3D,    &
                          DataY=GnuSeriesY3D,    &
                          DataXYZ=GnuSeriesXYZ,  &
                          terminal='pdf',        & 
                          label='myfig-3D'          )
    
    call fig2 % gnuplot3D(DataX=GnuSeriesX3D,       &
                          DataY=GnuSeriesY3D,       & 
                          DataXYZ=GnuSeriesXYZ,     &
                          terminal='screen',        & 
                          label='myfig-3D'          )
    
!   =============================================== double 3D PLOT ===========================================================================================
   
    call fig2 % setTitle(title = 'Two 3D plots on the same graph')
    call constructSeries(DataSeries = GnuSeriesXYZ1,    &
                                      title    = "XYZ1", &
                                      series   = xyz3   ) 
   
    pm3d=.false. !set filling that will distinguish the plots
    
    call fig2 % gnuplot3D_2(DataX=GnuSeriesX3D,    &
                          DataY=GnuSeriesY3D,    &
                          DataXYZ=GnuSeriesXYZ,  &
                          andDataXYZ=GnuSeriesXYZ1, &
                          terminal='pdf',        & 
                          label='myfig-3D-2'        )
   
    call fig2 % gnuplot3D_2(DataX=GnuSeriesX3D,       &
                            DataY=GnuSeriesY3D,       & 
                            DataXYZ=GnuSeriesXYZ,     &
                            andDataXYZ=GnuSeriesXYZ1, &
                            terminal='screen',        & 
                            label='myfig-3D-2'          )
   
!   =============================================== 3D HEAT MAP PLOT ===========================================================================================
    
    call fig3 % setTitle(title = '3D heatmap plot')
    call fig3 % setAxisLabels(xaxis='x', yaxis='y', zaxis='z')
    call fig3 % setDimension(dim=3)
   
    call fig3 % addCommand('set view map') !change view to map plot
    
    default_palette=heat_palette !change palette to default palette
    pm3d=.true. !if true uses pm3d mode to plot in 3D
    
    call constructSeries(DataSeries = GnuSeriesX3D,    &
                                      title    = "X", &
                                      series   = x3D   ) 
       
    call constructSeries(DataSeries = GnuSeriesY3D,    &
                                      title    = "Y", &
                                      series   = y3D   ) 
    
    call constructSeries(DataSeries = GnuSeriesXYZ,    &
                                      title    = "XYZ", &
                                      series   = xyz2   ) 
   
    call fig3 % gnuplot3D(DataX=GnuSeriesX3D,    &
                          DataY=GnuSeriesY3D,    &
                          DataXYZ=GnuSeriesXYZ,  &
                          terminal='pdf',        & 
                          label='myfig-3D-heat'          )
    
    call fig3 % gnuplot3D(DataX=GnuSeriesX3D,    &
                          DataY=GnuSeriesY3D,    &
                          DataXYZ=GnuSeriesXYZ,  &
                          terminal='screen',        & 
                          label='myfig-3D-heat'          )
    
     
!   =============================================== 3D HISTOGRAM ===========================================================================================
 
    call fig4 % setTitle(title = 'Histogram')
    call fig4 % setAxisLabels(xaxis='category', yaxis='frequency' )
    call fig4 % setDimension(dim=2)

    call constructSeries(DataSeries = GnuSeriesRnd1(1),     &
                                      title    = "series1",   &
                                      series   =  rmatrix1  ) 
    call constructSeries(DataSeries = GnuSeriesRnd1(2),     &
                                      title    = "series2",   &
                                      series   =  rmatrix2  )        
 

    call fig4 % gnuhistogram(DataX=GnuSeriesRnd1,    &
                              numbars = 10,          &
                              terminal='pdf',        & 
                              label='myhist'          )
    
   call fig4 % gnuhistogram(DataX=GnuSeriesRnd1,     &
                              numbars = 10,          &
                              terminal='screen',     & 
                              label='myhist'         )
    
 !=============================================== 3D SINGLE HISTOGRAM ===========================================================================================

    call constructSeries(DataSeries = GnuSeriesRnd(1),     &
                                      title    = "series2",   &
                                      series   =  rmatrix2  )    
    
   call fig4 % gnuhistogram(DataX=GnuSeriesRnd,    &
                              numbars = 10,          &
                              terminal='pdf',        & 
                              label='myhist0'          )
    
   call fig4 % gnuhistogram(DataX=GnuSeriesRnd,     &
                              numbars = 10,          &
                              terminal='screen',     & 
                              label='myhist0'         )
 
	end program test